Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(115)

Unified Diff: media/cast/net/cast_transport_defines.h

Issue 1534273002: Switch to standard integer types in media/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: more Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/cast/net/cast_transport_defines.h
diff --git a/media/cast/net/cast_transport_defines.h b/media/cast/net/cast_transport_defines.h
index bdd5494d662c4a233592fbede679c236160a1dc4..cddd055426ca2be34c75a3a1814d9b641c7a7760 100644
--- a/media/cast/net/cast_transport_defines.h
+++ b/media/cast/net/cast_transport_defines.h
@@ -12,7 +12,6 @@
#include <string>
#include <vector>
-#include "base/basictypes.h"
#include "base/memory/ref_counted.h"
#include "base/time/time.h"
@@ -41,10 +40,10 @@ const uint16_t kRtcpCastLastPacket = 0xfffe;
const size_t kMaxIpPacketSize = 1500;
-// Each uint16 represents one packet id within a cast frame.
+// Each uint16_t represents one packet id within a cast frame.
// Can also contain kRtcpCastAllPacketsLost and kRtcpCastLastPacket.
using PacketIdSet = std::set<uint16_t>;
// Each uint8 represents one cast frame.
using MissingFramesAndPacketsMap = std::map<uint8_t, PacketIdSet>;
using Packet = std::vector<uint8_t>;
@@ -60,8 +59,8 @@ class FrameIdWrapHelper {
explicit FrameIdWrapHelper(uint32_t start_frame_id)
: largest_frame_id_seen_(start_frame_id) {}
- uint32 MapTo32bitsFrameId(const uint8 over_the_wire_frame_id) {
- uint32 ret = (largest_frame_id_seen_ & ~0xff) | over_the_wire_frame_id;
+ uint32_t MapTo32bitsFrameId(const uint8_t over_the_wire_frame_id) {
+ uint32_t ret = (largest_frame_id_seen_ & ~0xff) | over_the_wire_frame_id;
// Add 1000 to both sides to avoid underflows.
if (1000 + ret - largest_frame_id_seen_ > 1000 + 127) {
ret -= 0x100;
@@ -77,7 +76,7 @@ class FrameIdWrapHelper {
private:
friend class FrameIdWrapHelperTest;
- uint32 largest_frame_id_seen_;
+ uint32_t largest_frame_id_seen_;
DISALLOW_COPY_AND_ASSIGN(FrameIdWrapHelper);
};
@@ -41,10 +40,10 @@ const uint16_t kRtcpCastLastPacket = 0xfffe;
// Can also contain kRtcpCastAllPacketsLost and kRtcpCastLastPacket.
using PacketIdSet = std::set<uint16_t>;
-// Each uint8 represents one cast frame.
+// Each uint8_t represents one cast frame.
using MissingFramesAndPacketsMap = std::map<uint8_t, PacketIdSet>;
using Packet = std::vector<uint8_t>;

Powered by Google App Engine
This is Rietveld 408576698